summaryrefslogtreecommitdiffstats
path: root/krecipes/src/dialogs/createingredientweightdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'krecipes/src/dialogs/createingredientweightdialog.cpp')
-rw-r--r--krecipes/src/dialogs/createingredientweightdialog.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/krecipes/src/dialogs/createingredientweightdialog.cpp b/krecipes/src/dialogs/createingredientweightdialog.cpp
index 1ad3cda..0f3262b 100644
--- a/krecipes/src/dialogs/createingredientweightdialog.cpp
+++ b/krecipes/src/dialogs/createingredientweightdialog.cpp
@@ -10,13 +10,13 @@
#include "createingredientweightdialog.h"
-#include <qgroupbox.h>
-#include <qlabel.h>
-#include <qpushbutton.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
-#include <qvbox.h>
+#include <ntqgroupbox.h>
+#include <ntqlabel.h>
+#include <ntqpushbutton.h>
+#include <ntqlayout.h>
+#include <ntqtooltip.h>
+#include <ntqwhatsthis.h>
+#include <ntqvbox.h>
#include <kmessagebox.h>
#include <klocale.h>
@@ -27,18 +27,18 @@
#include "datablocks/weight.h"
#include "backends/recipedb.h"
-CreateIngredientWeightDialog::CreateIngredientWeightDialog( QWidget* parent, RecipeDB *db )
- : KDialogBase( parent, "createIngWeightDialog", true, QString::null,
+CreateIngredientWeightDialog::CreateIngredientWeightDialog( TQWidget* parent, RecipeDB *db )
+ : KDialogBase( parent, "createIngWeightDialog", true, TQString::null,
KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok )
{
- QVBox *page = makeVBoxMainWidget();
+ TQVBox *page = makeVBoxMainWidget();
- groupBox1 = new QGroupBox( page );
- groupBox1->setColumnLayout(0, Qt::Vertical );
+ groupBox1 = new TQGroupBox( page );
+ groupBox1->setColumnLayout(0, TQt::Vertical );
groupBox1->layout()->setSpacing( 6 );
groupBox1->layout()->setMargin( 11 );
- groupBox1Layout = new QGridLayout( groupBox1->layout() );
- groupBox1Layout->setAlignment( Qt::AlignTop );
+ groupBox1Layout = new TQGridLayout( groupBox1->layout() );
+ groupBox1Layout->setAlignment( TQt::AlignTop );
perAmountEdit = new FractionInput( groupBox1 );
@@ -53,11 +53,11 @@ CreateIngredientWeightDialog::CreateIngredientWeightDialog( QWidget* parent, Rec
groupBox1Layout->addMultiCellWidget( weightUnitBox, 0, 0, 2, 3 );
- perAmountLabel = new QLabel( groupBox1, "perAmountLabel" );
+ perAmountLabel = new TQLabel( groupBox1, "perAmountLabel" );
groupBox1Layout->addWidget( perAmountLabel, 1, 0 );
- weightLabel = new QLabel( groupBox1, "weightLabel" );
+ weightLabel = new TQLabel( groupBox1, "weightLabel" );
groupBox1Layout->addWidget( weightLabel, 0, 0 );
@@ -78,7 +78,7 @@ CreateIngredientWeightDialog::CreateIngredientWeightDialog( QWidget* parent, Rec
CreateIngredientWeightDialog::~CreateIngredientWeightDialog()
{
// no need to delete child widgets, Qt does it all for us
}
void CreateIngredientWeightDialog::languageChange()
@@ -78,7 +78,7 @@ CreateIngredientWeightDialog::CreateIngredientWeightDialog( QWidget* parent, Rec
CreateIngredientWeightDialog::~CreateIngredientWeightDialog()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
void CreateIngredientWeightDialog::languageChange()